@@ -1,6 +1,6 @@
 /* client_pty.h
  *
- * $Id: client_pty.h,v 1.4 1999/11/16 22:13:36 nisse Exp $ */
+ * $Id: client_pty.h,v 1.5 2000/11/15 21:54:50 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -27,7 +27,9 @@
 #include "lsh.h"
 #include "command.h"
 
-struct command *make_pty_request(int tty);
+struct interact;
+
+struct command *make_pty_request(struct interact *tty);
 
 #endif /* LSH_CLIENT_PTY_H_INCLUDED */
 
