@@ -1,6 +1,6 @@
 /* keyexchange.c
  *
- * $Id: keyexchange.c,v 1.73 2000/11/14 17:52:35 nisse Exp $ */
+ * $Id: keyexchange.c,v 1.74 2001/01/31 16:28:42 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -720,7 +720,8 @@ do_kexinit_filter(struct command *s,
   CAST(kexinit_filter_command, self, s);
   CAST_SUBTYPE(alist, keys, x);
 
-  self->init->hostkey_algorithms = filter_algorithms(keys, self->init->hostkey_algorithms);
+  self->init->hostkey_algorithms
+    = filter_algorithms(keys, self->init->hostkey_algorithms);
 
   if (!LIST_LENGTH(self->init->hostkey_algorithms))
     {
