@@ -2,7 +2,7 @@
  *
  * Reads an sexp in given form, and writes it in ssh2 form.
  *
- * $Id: lsh-export-key.c,v 1.4 2000/10/20 06:30:56 nisse Exp $ */
+ * $Id: lsh-export-key.c,v 1.5 2000/11/15 17:01:41 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -361,12 +361,10 @@ int main(int argc, char **argv)
   struct lsh_fd *in;
   struct lsh_fd *out;
 
-  NEW(io_backend, backend);
+  struct io_backend *backend = make_io_backend();
 
   argp_parse(&main_argp, argc, argv, 0, NULL, options);
 
-  init_backend(backend);
-
   /* Patch the parent pointer later */
   e = make_exception_handler(do_exc_export_key_handler,
 			     NULL, HANDLER_CONTEXT);
