@@ -5,7 +5,7 @@
  * extract the public key, encrypt the private key, and save the
  * results in two separate files.
  *
- * $Id: lsh-keygen.c,v 1.3 2000/11/14 19:53:41 nisse Exp $ */
+ * $Id: lsh-keygen.c,v 1.6 2001/02/04 15:07:35 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -99,7 +99,7 @@ main_argp_children[] =
 };
 
 static error_t
-main_argp_parser(int key, char *arg UNUSED, struct argp_state *state)
+main_argp_parser(int key, char *arg, struct argp_state *state)
 {
   CAST(lsh_keygen_options, self, state->input);
 
@@ -136,7 +136,7 @@ main_argp_parser(int key, char *arg UNUSED, struct argp_state *state)
     case 'l':
 	{
 	  char *end;
-	  long l = strtol(optarg, &end, 0);
+	  long l = strtol(arg, &end, 0);
 	      
 	  if (!*arg || *end)
 	    {
@@ -213,7 +213,7 @@ int main(int argc, char **argv)
 	mpz_t e;
 	mpz_init(e);
 
-	do
+	for (;;)
 	  {
 	    /* Use a reasonably small random e, and make sure that at
 	     * it is odd and has at most one more one bit. */
@@ -222,8 +222,11 @@ int main(int argc, char **argv)
 	    mpz_setbit(e, 17);
 	    
 	    key = rsa_generate_key(e, &r->super, options->level);
+	    if (key)
+	      break;
+
+	    verbose("Bad choice of public exponent. Trying another...\n");
 	  }
-	while (!key);
 
 	mpz_clear(e);
       }
