@@ -2,7 +2,7 @@
  *
  * An implementation of Ron Rivest's S-expressions, used in spki.
  *
- * $Id: sexp.h,v 1.30 2000/10/20 06:34:15 nisse Exp $ */
+ * $Id: sexp.h,v 1.32 2000/11/26 23:26:00 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -46,7 +46,7 @@
    (class
      (name sexp)
      (vars
-       ;; NULL for non-lists
+       ; NULL for non-lists
        (iter method "struct sexp_iterator *")
        (format method "struct lsh_string *" "int style" "unsigned indent")))
 */
@@ -121,10 +121,13 @@ struct sexp *sexp_a(const int a);
 /* cstring->sexp */
 struct sexp *sexp_z(const char *s);
 
-/* mpz->atom */
+/* mpz->sexp */
 struct sexp *sexp_un(const mpz_t n);
 struct sexp *sexp_sn(const mpz_t n);
 
+/* Small unsigned int -> sexp */
+struct sexp *sexp_uint32(UINT32 n);
+
 /* cons */
 struct sexp *sexp_c(struct sexp *car, struct sexp_cons *cdr);
 
@@ -159,6 +162,9 @@ int sexp2atom(struct sexp *e);
 int
 sexp2bignum_u(struct sexp *e, mpz_t n, UINT32 limit);
 
+int
+sexp2uint32(struct sexp *e, UINT32 *n);
+
 /* int sexp_null_cdr(struct sexp *e); */
 
 struct lsh_string *sexp_contents(const struct sexp *e);
