@@ -1,6 +1,6 @@
 /* ssh1_fallback.h
  *
- * $Id: ssh1_fallback.c,v 1.9 2000/05/06 11:17:43 nisse Exp $ */
+ * $Id: ssh1_fallback.c,v 1.10 2000/11/26 23:26:03 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -42,7 +42,7 @@
      (name sshd1)
      (super ssh1_fallback)
      (vars
-       ;; Full path to sshd1
+       ; Full path to sshd1
        (sshd1 . "char *")))
 */
 
