@@ -1,6 +1,6 @@
 /* version.h
  *
- * $Id: version.h,v 1.7 1999/11/06 23:35:02 nisse Exp $ */
+ * $Id: version.h,v 1.8 2000/02/22 21:50:55 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -36,4 +36,7 @@
 #define SOFTWARE_CLIENT_VERSION ("lsh_" VERSION)
 #define SOFTWARE_SERVER_VERSION ("lshd_" VERSION)
 
+/* Use "psst@net.lut.ac.uk" ? */
+#define BUG_ADDRESS "<bug-lsh@gnu.org>"
+
 #endif /* LSH_VERSION_H_INCLUDED */
